@@ -320,6 +320,9 @@ INVALIDPARAMETERVALUE_OUTOFTIMERANGE = 'InvalidParameterValue.OutOfTimeRange'
 # 通道数量一次最多添加5000路
 INVALIDPARAMETERVALUE_PLANCHANNELSEXCEEDSRANGE = 'InvalidParameterValue.PlanChannelsExceedsRange'
 
+# 计划名称不能重复
+INVALIDPARAMETERVALUE_PLANNAMEREPEAT = 'InvalidParameterValue.PlanNameRepeat'
+
 # 一个取回任务最多添加32个设备通道
 INVALIDPARAMETERVALUE_RETRIEVETASKCHANNELSEXCEEDSRANGE = 'InvalidParameterValue.RetrieveTaskChannelsExceedsRange'
 
@@ -407,7 +410,7 @@ OPERATIONDENIED_EXCEEDEDMAXIMUMDEPTH = 'OperationDenied.ExceededMaximumDepth'
 # 资源不可达，该资源不属于该地域
 REGIONERROR_RESOURCEUNREACHABLE = 'RegionError.ResourceUnreachable'
 
-# 所有通道都已添加计划，不能重复添加
+# 存在重复添加的通道
 RESOURCEINUSE_CHANNELREPEATADD = 'ResourceInUse.ChannelRepeatAdd'
 
 # 计划删除中无法修改
@@ -490,3 +493,6 @@ UNSUPPORTEDOPERATION_SCALEANDPOSBOTHEXIST = 'UnsupportedOperation.ScaleAndPosBot
 
 # StreamType和Resolution参数不支持同时下发
 UNSUPPORTEDOPERATION_STREAMTYPEORRESOLUTION = 'UnsupportedOperation.StreamTypeOrResolution'
+
+# 该地域未开通内网服务
+UNSUPPORTEDOPERATION_UNOPENEDINTRANETSERVICESINREGION = 'UnsupportedOperation.UnopenedIntranetServicesInRegion'
